# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added
### Changed
### Deprecated
### Removed
### Fixed
### Security

## [0.0.2] - 2020-10-11

### Added
- Added support for Python 3.9.

## [0.0.1] - 2020-10-10

First release, starting with two basic models:
`RandomSegmenter` and `LongestStringMatching`.
